import * as i0 from '@angular/core';
import { Injectable, EventEmitter, forwardRef, ViewChild, Output, Input, Component } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import * as i3 from '@angular/common';
import { CommonModule } from '@angular/common';

class SyntaxHighlightService {
    highlightHtml(content) {
        if (!content)
            return '';
        const tokens = this.tokenizeHtml(content);
        return this.applyHighlighting(tokens, content);
    }
    tokenizeHtml(content) {
        const tokens = [];
        let index = 0;
        while (index < content.length) {
            // HTML Comments
            if (content.substring(index, index + 4) === '<!--') {
                const endIndex = content.indexOf('-->', index);
                if (endIndex !== -1) {
                    tokens.push({
                        type: 'comment',
                        value: content.substring(index, endIndex + 3),
                        startIndex: index,
                        endIndex: endIndex + 3
                    });
                    index = endIndex + 3;
                    continue;
                }
            }
            // HTML Tags
            if (content[index] === '<') {
                const tagEndIndex = content.indexOf('>', index);
                if (tagEndIndex !== -1) {
                    const tagContent = content.substring(index, tagEndIndex + 1);
                    // Parse tag and attributes
                    const tagMatch = tagContent.match(/^<\/?([a-zA-Z][a-zA-Z0-9]*)/);
                    if (tagMatch) {
                        // Tag name
                        tokens.push({
                            type: 'tag',
                            value: tagMatch[0],
                            startIndex: index,
                            endIndex: index + tagMatch[0].length
                        });
                        // Parse attributes
                        const attributeRegex = /\s+([a-zA-Z][a-zA-Z0-9-]*)\s*=\s*("[^"]*"|'[^']*'|[^\s>]*)/g;
                        let attrMatch;
                        let lastIndex = index + tagMatch[0].length;
                        while ((attrMatch = attributeRegex.exec(tagContent)) !== null) {
                            const attrStartIndex = index + attrMatch.index;
                            // Attribute name
                            tokens.push({
                                type: 'attribute',
                                value: attrMatch[1],
                                startIndex: attrStartIndex + attrMatch[0].indexOf(attrMatch[1]),
                                endIndex: attrStartIndex + attrMatch[0].indexOf(attrMatch[1]) + attrMatch[1].length
                            });
                            // Attribute value
                            tokens.push({
                                type: 'string',
                                value: attrMatch[2],
                                startIndex: attrStartIndex + attrMatch[0].indexOf(attrMatch[2]),
                                endIndex: attrStartIndex + attrMatch[0].indexOf(attrMatch[2]) + attrMatch[2].length
                            });
                        }
                    }
                    index = tagEndIndex + 1;
                    continue;
                }
            }
            // Text content
            const nextTagIndex = content.indexOf('<', index);
            const textEnd = nextTagIndex === -1 ? content.length : nextTagIndex;
            if (textEnd > index) {
                const textContent = content.substring(index, textEnd);
                if (textContent.trim()) {
                    tokens.push({
                        type: 'text',
                        value: textContent,
                        startIndex: index,
                        endIndex: textEnd
                    });
                }
                index = textEnd;
            }
            else {
                index++;
            }
        }
        return tokens;
    }
    applyHighlighting(tokens, originalContent) {
        let result = '';
        let lastIndex = 0;
        // Sort tokens by start index
        tokens.sort((a, b) => a.startIndex - b.startIndex);
        for (const token of tokens) {
            // Add any content between tokens
            if (token.startIndex > lastIndex) {
                result += this.escapeHtml(originalContent.substring(lastIndex, token.startIndex));
            }
            // Add highlighted token
            const escapedValue = this.escapeHtml(token.value);
            result += `<span class="html-editor-${token.type}">${escapedValue}</span>`;
            lastIndex = token.endIndex;
        }
        // Add remaining content
        if (lastIndex < originalContent.length) {
            result += this.escapeHtml(originalContent.substring(lastIndex));
        }
        return result;
    }
    escapeHtml(text) {
        const div = document.createElement('div');
        div.textContent = text;
        return div.innerHTML;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SyntaxHighlightService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SyntaxHighlightService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: SyntaxHighlightService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class EditorConfigService {
    getDefaultConfig() {
        return {
            tabSize: 2,
            autoIndent: true,
            lineNumbers: true,
            wordWrap: false,
            fontSize: '14px'
        };
    }
    validateConfig(config) {
        if (!config)
            return false;
        return (typeof config.tabSize === 'number' &&
            config.tabSize > 0 &&
            config.tabSize <= 8 &&
            typeof config.autoIndent === 'boolean' &&
            typeof config.lineNumbers === 'boolean' &&
            typeof config.wordWrap === 'boolean' &&
            typeof config.fontSize === 'string' &&
            this.isValidFontSize(config.fontSize));
    }
    mergeWithDefaults(config) {
        const defaultConfig = this.getDefaultConfig();
        return { ...defaultConfig, ...config };
    }
    isValidFontSize(fontSize) {
        // Check if fontSize is a valid CSS font-size value
        const validUnits = ['px', 'em', 'rem', '%', 'pt'];
        return validUnits.some(unit => fontSize.endsWith(unit)) &&
            !isNaN(parseFloat(fontSize));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: EditorConfigService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: EditorConfigService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: EditorConfigService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class HtmlEditorComponent {
    syntaxHighlightService;
    editorConfigService;
    cdr;
    config = {
        tabSize: 2,
        autoIndent: true,
        lineNumbers: true,
        wordWrap: false,
        fontSize: '14px'
    };
    theme = 'default';
    readonly = false;
    placeholder = 'Enter HTML content...';
    contentChange = new EventEmitter();
    focus = new EventEmitter();
    blur = new EventEmitter();
    editorTextarea;
    value = '';
    highlightedContent = '';
    lineNumbers = [];
    onChange = (value) => { };
    onTouched = () => { };
    isDisabled = false;
    constructor(syntaxHighlightService, editorConfigService, cdr) {
        this.syntaxHighlightService = syntaxHighlightService;
        this.editorConfigService = editorConfigService;
        this.cdr = cdr;
    }
    ngOnChanges(changes) {
        if (changes['config']) {
            this.config = this.editorConfigService.mergeWithDefaults(this.config);
        }
        if (changes['value'] || changes['config']) {
            this.updateHighlighting();
            this.updateLineNumbers();
        }
    }
    ngAfterViewInit() {
        this.updateHighlighting();
        this.updateLineNumbers();
    }
    ngOnDestroy() {
        // Cleanup if needed
    }
    // ControlValueAccessor implementation
    writeValue(value) {
        this.value = value || '';
        this.updateHighlighting();
        this.updateLineNumbers();
        this.cdr.detectChanges();
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
        this.readonly = isDisabled;
        this.cdr.detectChanges();
    }
    // Event handlers
    handleInput(event) {
        const target = event.target;
        this.value = target.value;
        this.onChange(this.value);
        this.contentChange.emit(this.value);
        this.updateHighlighting();
        this.updateLineNumbers();
        // Handle auto-indentation for closing tags
        if (this.config.autoIndent) {
            setTimeout(() => this.handleClosingTagIndentation(), 0);
        }
    }
    handleKeydown(event) {
        if (this.readonly || this.isDisabled)
            return;
        // Handle Tab key for indentation
        if (event.key === 'Tab') {
            event.preventDefault();
            this.insertTab(event.shiftKey);
            return;
        }
        // Handle Enter key for auto-indentation
        if (event.key === 'Enter' && this.config.autoIndent) {
            event.preventDefault();
            this.handleAutoIndentation();
            return;
        }
        // Handle closing tag auto-indentation
        if (event.key === '>' && this.config.autoIndent) {
            setTimeout(() => this.handleClosingTagIndentation(), 0);
        }
    }
    handleFocus() {
        this.focus.emit();
    }
    handleBlur() {
        this.onTouched();
        this.blur.emit();
    }
    handleScroll(event) {
        const target = event.target;
        const highlightLayer = target.parentElement?.querySelector('.html-editor-highlight-layer');
        const lineNumbers = target.parentElement?.parentElement?.querySelector('.html-editor-line-numbers');
        if (highlightLayer) {
            highlightLayer.scrollTop = target.scrollTop;
            highlightLayer.scrollLeft = target.scrollLeft;
        }
        if (lineNumbers) {
            lineNumbers.scrollTop = target.scrollTop;
        }
    }
    // Helper methods
    updateHighlighting() {
        this.highlightedContent = this.syntaxHighlightService.highlightHtml(this.value);
    }
    updateLineNumbers() {
        const lines = this.value.split('\n').length;
        this.lineNumbers = Array.from({ length: lines }, (_, i) => i + 1);
    }
    insertTab(isShiftTab) {
        const textarea = this.editorTextarea.nativeElement;
        const start = textarea.selectionStart;
        const end = textarea.selectionEnd;
        const spaces = ' '.repeat(this.config.tabSize);
        if (isShiftTab) {
            // Remove indentation
            const beforeCursor = this.value.substring(0, start);
            const afterCursor = this.value.substring(end);
            const lineStart = beforeCursor.lastIndexOf('\n') + 1;
            const lineBeforeCursor = beforeCursor.substring(lineStart);
            if (lineBeforeCursor.startsWith(spaces)) {
                const newValue = beforeCursor.substring(0, lineStart) +
                    lineBeforeCursor.substring(this.config.tabSize) +
                    afterCursor;
                this.updateValue(newValue, start - this.config.tabSize, end - this.config.tabSize);
            }
        }
        else {
            // Add indentation
            const newValue = this.value.substring(0, start) + spaces + this.value.substring(end);
            this.updateValue(newValue, start + this.config.tabSize, start + this.config.tabSize);
        }
    }
    handleAutoIndentation() {
        const textarea = this.editorTextarea.nativeElement;
        const start = textarea.selectionStart;
        const beforeCursor = this.value.substring(0, start);
        const afterCursor = this.value.substring(start);
        const currentLineStart = beforeCursor.lastIndexOf('\n') + 1;
        const currentLine = beforeCursor.substring(currentLineStart);
        // Calculate indentation level
        const indentMatch = currentLine.match(/^(\s*)/);
        let indent = indentMatch ? indentMatch[1] : '';
        // Check if we're inside a tag that should increase indentation
        const openTagMatch = currentLine.match(/<([a-zA-Z][a-zA-Z0-9]*)[^>]*>$/);
        const isOpeningTag = openTagMatch && !currentLine.includes(`</${openTagMatch[1]}>`);
        // Check if the next content is IMMEDIATELY a closing tag (no whitespace, same line)
        const immediateClosingTagMatch = afterCursor.match(/^<\/([a-zA-Z][a-zA-Z0-9]*)/);
        const isImmediatelyBeforeClosingTag = immediateClosingTagMatch && openTagMatch &&
            immediateClosingTagMatch[1] === openTagMatch[1];
        if (isOpeningTag) {
            const tagIndent = indent + ' '.repeat(this.config.tabSize);
            if (isImmediatelyBeforeClosingTag) {
                // Only add extra line if closing tag is IMMEDIATELY after opening tag with no content
                // Example: <div>|</div> -> should become <div>\n  |\n</div>
                const newValue = beforeCursor + '\n' + tagIndent + '\n' + indent + afterCursor;
                this.updateValue(newValue, start + 1 + tagIndent.length, start + 1 + tagIndent.length);
            }
            else {
                // Normal case: just add increased indentation
                // Example: <div>| -> should become <div>\n  |
                const newValue = beforeCursor + '\n' + tagIndent + afterCursor;
                this.updateValue(newValue, start + 1 + tagIndent.length, start + 1 + tagIndent.length);
            }
        }
        else {
            // Normal indentation - maintain current level
            const newValue = beforeCursor + '\n' + indent + afterCursor;
            this.updateValue(newValue, start + 1 + indent.length, start + 1 + indent.length);
        }
    }
    handleClosingTagIndentation() {
        const textarea = this.editorTextarea.nativeElement;
        const start = textarea.selectionStart;
        const beforeCursor = this.value.substring(0, start);
        // Check if we just typed a closing tag
        const closingTagMatch = beforeCursor.match(/<\/([a-zA-Z][a-zA-Z0-9]*)>$/);
        if (!closingTagMatch)
            return;
        const tagName = closingTagMatch[1];
        const currentLineStart = beforeCursor.lastIndexOf('\n') + 1;
        const currentLine = beforeCursor.substring(currentLineStart);
        // Find the matching opening tag to determine proper indentation
        const openingTagIndent = this.findMatchingOpeningTagIndent(beforeCursor.substring(0, currentLineStart), tagName);
        if (openingTagIndent === null)
            return;
        // Get current indentation of the closing tag line
        const currentIndentMatch = currentLine.match(/^(\s*)/);
        const currentIndent = currentIndentMatch ? currentIndentMatch[1] : '';
        // If the indentation is already correct, don't change it
        if (currentIndent === openingTagIndent)
            return;
        // Replace current line indentation with correct indentation
        const lineContentAfterIndent = currentLine.substring(currentIndent.length);
        const newLine = openingTagIndent + lineContentAfterIndent;
        const newValue = beforeCursor.substring(0, currentLineStart) + newLine + this.value.substring(start);
        const newCursorPosition = start + (openingTagIndent.length - currentIndent.length);
        this.updateValue(newValue, newCursorPosition, newCursorPosition);
    }
    findMatchingOpeningTagIndent(content, tagName) {
        const lines = content.split('\n');
        let tagStack = [];
        for (let i = 0; i < lines.length; i++) {
            const line = lines[i];
            const indentMatch = line.match(/^(\s*)/);
            const indent = indentMatch ? indentMatch[1] : '';
            // Find all tags in this line
            const tagRegex = /<\/?([a-zA-Z][a-zA-Z0-9]*)[^>]*>/g;
            let match;
            while ((match = tagRegex.exec(line)) !== null) {
                const fullTag = match[0];
                const currentTagName = match[1];
                if (fullTag.startsWith('</')) {
                    // Closing tag - pop from stack
                    if (tagStack.length > 0 && tagStack[tagStack.length - 1].name === currentTagName) {
                        tagStack.pop();
                    }
                }
                else if (!fullTag.endsWith('/>')) {
                    // Opening tag (not self-closing) - push to stack
                    tagStack.push({ name: currentTagName, indent });
                }
            }
        }
        // Find the matching opening tag for our closing tag
        for (let i = tagStack.length - 1; i >= 0; i--) {
            if (tagStack[i].name === tagName) {
                return tagStack[i].indent;
            }
        }
        return null;
    }
    updateValue(newValue, selectionStart, selectionEnd) {
        this.value = newValue;
        this.onChange(this.value);
        this.contentChange.emit(this.value);
        this.updateHighlighting();
        this.updateLineNumbers();
        // Restore cursor position
        setTimeout(() => {
            const textarea = this.editorTextarea.nativeElement;
            textarea.setSelectionRange(selectionStart, selectionEnd);
        });
    }
    trackByLineNumber(index, lineNumber) {
        return lineNumber;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: HtmlEditorComponent, deps: [{ token: SyntaxHighlightService }, { token: EditorConfigService }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.14", type: HtmlEditorComponent, isStandalone: true, selector: "witspry-html-editor", inputs: { config: "config", theme: "theme", readonly: "readonly", placeholder: "placeholder" }, outputs: { contentChange: "contentChange", focus: "focus", blur: "blur" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => HtmlEditorComponent),
                multi: true
            }
        ], viewQueries: [{ propertyName: "editorTextarea", first: true, predicate: ["editorTextarea"], descendants: true }], usesOnChanges: true, ngImport: i0, template: `
    <div class="html-editor-container" [attr.data-theme]="theme">
      <div class="html-editor-wrapper">
        <!-- Line Numbers -->
        <div 
          *ngIf="config.lineNumbers" 
          class="html-editor-line-numbers"
          [style.font-size]="config.fontSize">
          <div 
            *ngFor="let lineNumber of lineNumbers; trackBy: trackByLineNumber" 
            class="html-editor-line-number">
            {{ lineNumber }}
          </div>
        </div>
        
        <!-- Editor Content -->
        <div class="html-editor-content">
          <!-- Syntax Highlighted Background -->
          <div 
            class="html-editor-highlight-layer"
            [style.font-size]="config.fontSize"
            [innerHTML]="highlightedContent">
          </div>
          
          <!-- Editable Text Area -->
          <textarea
            #editorTextarea
            class="html-editor-textarea"
            [style.font-size]="config.fontSize"
            [style.tab-size]="config.tabSize"
            [placeholder]="placeholder"
            [readonly]="readonly"
            [value]="value"
            (input)="handleInput($event)"
            (keydown)="handleKeydown($event)"
            (focus)="handleFocus()"
            (blur)="handleBlur()"
            (scroll)="handleScroll($event)"
            spellcheck="false"
            autocomplete="off"
            autocorrect="off"
            autocapitalize="off">
          </textarea>
        </div>
      </div>
    </div>
  `, isInline: true, styles: [".html-editor-container{--editor-bg: #ffffff;--editor-text: #333333;--editor-border: #d1d5db;--editor-line-number-bg: #f9fafb;--editor-line-number-text: #6b7280;--editor-selection: #3b82f6;--editor-tag: #dc2626;--editor-attribute: #059669;--editor-string: #7c3aed;--editor-comment: #6b7280;--editor-text-content: #374151;position:relative;border:1px solid var(--editor-border);border-radius:6px;overflow:hidden;font-family:Consolas,Monaco,Courier New,monospace;background:var(--editor-bg)}.html-editor-container[data-theme=dark]{--editor-bg: #1f2937;--editor-text: #f9fafb;--editor-border: #374151;--editor-line-number-bg: #111827;--editor-line-number-text: #9ca3af;--editor-selection: #3b82f6;--editor-tag: #f87171;--editor-attribute: #34d399;--editor-string: #a78bfa;--editor-comment: #9ca3af;--editor-text-content: #d1d5db}.html-editor-container[data-theme=light]{--editor-bg: #fefefe;--editor-text: #1f2937;--editor-border: #e5e7eb;--editor-line-number-bg: #f8fafc;--editor-line-number-text: #64748b;--editor-selection: #2563eb;--editor-tag: #dc2626;--editor-attribute: #059669;--editor-string: #7c3aed;--editor-comment: #64748b;--editor-text-content: #334155}.html-editor-wrapper{display:flex;min-height:200px;max-height:500px;position:relative}.html-editor-line-numbers{background:var(--editor-line-number-bg);color:var(--editor-line-number-text);padding:8px 12px 8px 8px;border-right:1px solid var(--editor-border);-webkit-user-select:none;user-select:none;overflow:hidden;min-width:40px;text-align:right;line-height:1.5;font-size:14px}.html-editor-line-number{white-space:nowrap;height:1.5em;display:flex;align-items:center;justify-content:flex-end}.html-editor-content{flex:1;position:relative;overflow:hidden}.html-editor-highlight-layer{position:absolute;inset:0;padding:8px 12px;margin:0;border:none;background:transparent;color:transparent;font-family:inherit;font-size:inherit;line-height:1.5;white-space:pre-wrap;word-wrap:break-word;overflow:hidden;pointer-events:none;z-index:1}.html-editor-textarea{position:absolute;inset:0;width:100%;height:100%;padding:8px 12px;margin:0;border:none;outline:none;background:transparent;color:var(--editor-text);font-family:inherit;font-size:inherit;line-height:1.5;white-space:pre-wrap;word-wrap:break-word;resize:none;z-index:2;caret-color:var(--editor-text)}.html-editor-textarea::placeholder{color:var(--editor-line-number-text);opacity:.7}.html-editor-textarea:focus{outline:none}.html-editor-textarea::selection{background:var(--editor-selection);color:#fff}.html-editor-tag{color:var(--editor-tag);font-weight:600}.html-editor-attribute{color:var(--editor-attribute);font-weight:500}.html-editor-string{color:var(--editor-string)}.html-editor-comment{color:var(--editor-comment);font-style:italic}.html-editor-text{color:var(--editor-text-content)}.html-editor-textarea::-webkit-scrollbar{width:8px;height:8px}.html-editor-textarea::-webkit-scrollbar-track{background:var(--editor-line-number-bg)}.html-editor-textarea::-webkit-scrollbar-thumb{background:var(--editor-line-number-text);border-radius:4px}.html-editor-textarea::-webkit-scrollbar-thumb:hover{background:var(--editor-text)}.html-editor-container[data-readonly=true] .html-editor-textarea{cursor:default;background:var(--editor-line-number-bg)}.html-editor-container:focus-within{border-color:var(--editor-selection);box-shadow:0 0 0 2px #3b82f61a}@media (max-width: 768px){.html-editor-line-numbers{min-width:35px;padding:8px 8px 8px 4px}.html-editor-textarea,.html-editor-highlight-layer{padding:8px}}@media (prefers-contrast: high){.html-editor-container{--editor-border: #000000;--editor-text: #000000;--editor-bg: #ffffff}.html-editor-container[data-theme=dark]{--editor-border: #ffffff;--editor-text: #ffffff;--editor-bg: #000000}}@media (prefers-reduced-motion: reduce){.html-editor-container{transition:none}}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i3.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i3.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: HtmlEditorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'witspry-html-editor', standalone: true, imports: [CommonModule], template: `
    <div class="html-editor-container" [attr.data-theme]="theme">
      <div class="html-editor-wrapper">
        <!-- Line Numbers -->
        <div 
          *ngIf="config.lineNumbers" 
          class="html-editor-line-numbers"
          [style.font-size]="config.fontSize">
          <div 
            *ngFor="let lineNumber of lineNumbers; trackBy: trackByLineNumber" 
            class="html-editor-line-number">
            {{ lineNumber }}
          </div>
        </div>
        
        <!-- Editor Content -->
        <div class="html-editor-content">
          <!-- Syntax Highlighted Background -->
          <div 
            class="html-editor-highlight-layer"
            [style.font-size]="config.fontSize"
            [innerHTML]="highlightedContent">
          </div>
          
          <!-- Editable Text Area -->
          <textarea
            #editorTextarea
            class="html-editor-textarea"
            [style.font-size]="config.fontSize"
            [style.tab-size]="config.tabSize"
            [placeholder]="placeholder"
            [readonly]="readonly"
            [value]="value"
            (input)="handleInput($event)"
            (keydown)="handleKeydown($event)"
            (focus)="handleFocus()"
            (blur)="handleBlur()"
            (scroll)="handleScroll($event)"
            spellcheck="false"
            autocomplete="off"
            autocorrect="off"
            autocapitalize="off">
          </textarea>
        </div>
      </div>
    </div>
  `, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => HtmlEditorComponent),
                            multi: true
                        }
                    ], styles: [".html-editor-container{--editor-bg: #ffffff;--editor-text: #333333;--editor-border: #d1d5db;--editor-line-number-bg: #f9fafb;--editor-line-number-text: #6b7280;--editor-selection: #3b82f6;--editor-tag: #dc2626;--editor-attribute: #059669;--editor-string: #7c3aed;--editor-comment: #6b7280;--editor-text-content: #374151;position:relative;border:1px solid var(--editor-border);border-radius:6px;overflow:hidden;font-family:Consolas,Monaco,Courier New,monospace;background:var(--editor-bg)}.html-editor-container[data-theme=dark]{--editor-bg: #1f2937;--editor-text: #f9fafb;--editor-border: #374151;--editor-line-number-bg: #111827;--editor-line-number-text: #9ca3af;--editor-selection: #3b82f6;--editor-tag: #f87171;--editor-attribute: #34d399;--editor-string: #a78bfa;--editor-comment: #9ca3af;--editor-text-content: #d1d5db}.html-editor-container[data-theme=light]{--editor-bg: #fefefe;--editor-text: #1f2937;--editor-border: #e5e7eb;--editor-line-number-bg: #f8fafc;--editor-line-number-text: #64748b;--editor-selection: #2563eb;--editor-tag: #dc2626;--editor-attribute: #059669;--editor-string: #7c3aed;--editor-comment: #64748b;--editor-text-content: #334155}.html-editor-wrapper{display:flex;min-height:200px;max-height:500px;position:relative}.html-editor-line-numbers{background:var(--editor-line-number-bg);color:var(--editor-line-number-text);padding:8px 12px 8px 8px;border-right:1px solid var(--editor-border);-webkit-user-select:none;user-select:none;overflow:hidden;min-width:40px;text-align:right;line-height:1.5;font-size:14px}.html-editor-line-number{white-space:nowrap;height:1.5em;display:flex;align-items:center;justify-content:flex-end}.html-editor-content{flex:1;position:relative;overflow:hidden}.html-editor-highlight-layer{position:absolute;inset:0;padding:8px 12px;margin:0;border:none;background:transparent;color:transparent;font-family:inherit;font-size:inherit;line-height:1.5;white-space:pre-wrap;word-wrap:break-word;overflow:hidden;pointer-events:none;z-index:1}.html-editor-textarea{position:absolute;inset:0;width:100%;height:100%;padding:8px 12px;margin:0;border:none;outline:none;background:transparent;color:var(--editor-text);font-family:inherit;font-size:inherit;line-height:1.5;white-space:pre-wrap;word-wrap:break-word;resize:none;z-index:2;caret-color:var(--editor-text)}.html-editor-textarea::placeholder{color:var(--editor-line-number-text);opacity:.7}.html-editor-textarea:focus{outline:none}.html-editor-textarea::selection{background:var(--editor-selection);color:#fff}.html-editor-tag{color:var(--editor-tag);font-weight:600}.html-editor-attribute{color:var(--editor-attribute);font-weight:500}.html-editor-string{color:var(--editor-string)}.html-editor-comment{color:var(--editor-comment);font-style:italic}.html-editor-text{color:var(--editor-text-content)}.html-editor-textarea::-webkit-scrollbar{width:8px;height:8px}.html-editor-textarea::-webkit-scrollbar-track{background:var(--editor-line-number-bg)}.html-editor-textarea::-webkit-scrollbar-thumb{background:var(--editor-line-number-text);border-radius:4px}.html-editor-textarea::-webkit-scrollbar-thumb:hover{background:var(--editor-text)}.html-editor-container[data-readonly=true] .html-editor-textarea{cursor:default;background:var(--editor-line-number-bg)}.html-editor-container:focus-within{border-color:var(--editor-selection);box-shadow:0 0 0 2px #3b82f61a}@media (max-width: 768px){.html-editor-line-numbers{min-width:35px;padding:8px 8px 8px 4px}.html-editor-textarea,.html-editor-highlight-layer{padding:8px}}@media (prefers-contrast: high){.html-editor-container{--editor-border: #000000;--editor-text: #000000;--editor-bg: #ffffff}.html-editor-container[data-theme=dark]{--editor-border: #ffffff;--editor-text: #ffffff;--editor-bg: #000000}}@media (prefers-reduced-motion: reduce){.html-editor-container{transition:none}}\n"] }]
        }], ctorParameters: () => [{ type: SyntaxHighlightService }, { type: EditorConfigService }, { type: i0.ChangeDetectorRef }], propDecorators: { config: [{
                type: Input
            }], theme: [{
                type: Input
            }], readonly: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], contentChange: [{
                type: Output
            }], focus: [{
                type: Output
            }], blur: [{
                type: Output
            }], editorTextarea: [{
                type: ViewChild,
                args: ['editorTextarea', { static: false }]
            }] } });

class WitspryNgHtmlEditorService {
    constructor() { }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: WitspryNgHtmlEditorService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: WitspryNgHtmlEditorService, providedIn: 'root' });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.14", ngImport: i0, type: WitspryNgHtmlEditorService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [] });

// Re-export the main HTML editor component for backward compatibility

/*
 * Public API Surface of witspry-ng-html-editor
 */
// Main component

/**
 * Generated bundle index. Do not edit.
 */

export { EditorConfigService, HtmlEditorComponent, SyntaxHighlightService, HtmlEditorComponent as WitspryNgHtmlEditorComponent, WitspryNgHtmlEditorService };
//# sourceMappingURL=witspry-ng-html-editor.mjs.map
